/*
 * Copyright 2005, 2006 University of Leiden.
 *
 * This file is part of MIA+EWS.
 *
 * MIA+EWS is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * MIA+EWS is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with MIA; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
/*******************************************************************************
* E.S.O. - VLT project
*
* "@(#) $Id: oi_target.h,v 1.1 2010/01/24 10:57:38 jaffe Exp $"
*
* who       when      what
* --------  --------  ----------------------------------------------
* jaffe 2010-01-21  written
*/

/************************************************************************
 *
 *----------------------------------------------------------------------
 */
/* $Id: oi_target.h,v 1.1 2010/01/24 10:57:38 jaffe Exp $ */

#ifndef _OI_TARGET_TABLE_H
#define _OI_TARGET_TABLE_H
/*----------------------------------------------------------------------- */
/* target table FITS binary tables routines                                */
/*----------------------------------------------------------------------- */
#include "VLTItable.h"

typedef struct      /* table definition for oi_target table */
{
  table_def *def;       /* basic table information */
  long   row;           /* last row (0-rel) read or written, -1=> none. */
  int    target_id_col; 
  int    target_col; 
  int    raep0_col; 
  int    decep0_col; 
  int    equinox_col; 
  int    ra_err_col; 
  int    dec_err_col; 
  int    sysvel_col; 
  int    veltyp_col; 
  int    veldef_col; 
  int    pmra_col; 
  int    pmdec_col; 
  int    pmra_err_col; 
  int    pmdec_err_col; 
  int    parallax_col; 
  int    para_err_col;      
  int    spectyp_col;      
} target_table_def;

typedef struct      /* structure used for target row */
{
  int      target_id;     
  char     target[18];
  double   raep0;
  double   decep0;
  float    equinox;
  double   ra_err;
  double   dec_err;
  double   sysvel;
  char     veltyp[10];
  char     veldef[10];
  double   pmra;
  double   pmdec;
  double   pmra_err;
  double   pmdec_err;
  float    parallax;
  float    para_err;
  char     spectyp[18];
  table_row *raw;    /* generic table row */
} target_table_row;

/* public functions */

/* target_table_row functions */
  target_table_row* make_target_table_row(target_table_def* table);
/*----------------------------------------------------------------------- */
/*   Make an target_table_row structure                           */
/*   Inputs:                                                              */
/*      table     pointer to target_table table structure         */
/*   Returns:                                                             */
/*      An target_table_row structure pointer ; NULL => failure   */
/*      Data pointers set to generic structure values                     */
/*----------------------------------------------------------------------- */

void kill_target_table_row (target_table_row *row);
/*----------------------------------------------------------------------- */
/*   Delete an target_table_row structure                         */
/*   Inputs:                                                              */
/*      row    pointer to the target_table_row structure.         */
/*----------------------------------------------------------------------- */

/* target_table functions */

target_table_def* 
make_target_table_def(fitsfile *fptr, int *ierr);
/*----------------------------------------------------------------------- */
/*   Make a new target_table in an open FITS file                 */
/*   Inputs:                                                              */
/*      fptr      cfitsio pointer to open FITS file                       */
/*   Output:                                                              */
/*      ierr      Error code: 0 => ok, checked on input                   */
/*   Returns:                                                             */
/*      A target_table_def pointer; NULL indicates failure        */
/*----------------------------------------------------------------------- */

target_table_def* 
open_target_table(fitsfile *fptr, int *ierr);
/*----------------------------------------------------------------------- */
/*   Open an existing target_table in the active FITS file        */
/*   Inputs:                                                              */
/*      fptr      cfitsio pointer to open FITS file                       */
/*   Output:                                                              */
/*      ierr      Error code: 0 => ok, checked on input                   */
/*   Returns:                                                             */
/*      An target_table_def pointer; NULL indicates failure       */
/*----------------------------------------------------------------------- */

int read_target_table(fitsfile *fptr,  target_table_def* table, 
			    target_table_row *row, long row_number,
			    int *ierr);
/*----------------------------------------------------------------------- */
/*   Read the next row from an target_table                       */
/*   Inputs:                                                              */
/*      fptr      cfitsio pointer to open FITS file                       */
/*      table     table definitions structure from open or create         */
/*      row_number which row (1-rel) in the table                         */   
/*                 -1 => next row                                         */  
/*   Input/output:                                                        */
/*      row       pointer to an extant row structure                      */
/*      ierr      Error code: 0 => ok, checked on input                   */
/*   Returns:                                                             */
/*      0 if successful, else failed                                      */
/*----------------------------------------------------------------------- */

int write_target_table(fitsfile *fptr, target_table_def *table, 
			     target_table_row *row,  long row_number,
			     int *ierr);
/*----------------------------------------------------------------------- */
/*   Write  the next row to an target_table                               */
/*   Inputs:                                                              */
/*      fptr      cfitsio pointer to open FITS file                       */
/*      table     table definitions structure from open or create         */
/*      row       pointer to an extant row structure                      */
/*      row_number which row (1-rel) in the table                         */
/*                 -1 => next row                                         */  
/*   Input/output:                                                        */
/*      ierr      Error code: 0 => ok, checked on input                   */
/*   Returns:                                                             */
/*      0 if successful, else failed                                      */
/*----------------------------------------------------------------------- */

int close_target_table(fitsfile *fptr, target_table_def* table, 
			     int *ierr);
/*----------------------------------------------------------------------- */
/*   Close an open target_table, associated structures are        */
/*   destroyed                                                            */
/*   Note: this closes the full FITS file                                 */
/*   Inputs:                                                              */
/*      fptr      cfitsio pointer to open FITS file                       */
/*   Returns:                                                             */
/*      0 if successful, else failed                                      */
/*----------------------------------------------------------------------- */

void kill_target_table_def (target_table_def* table);
/*----------------------------------------------------------------------- */
/*   Delete an target_table structure                             */
/*   Inputs:                                                              */
/*      table     table definitions structure from open or create         */
/*----------------------------------------------------------------------- */

void get_target_info(target_table_def *table);
#endif /* end _OI_TARGET_TABLE_H */
/* */
